import net.nanex.NxCoreClass;
class DetailedTradeSample extends NxCoreClass{
    
    @Override
    public int OnNxCoreCallback(NxCoreSystem nxCoreSys, NxCoreMessage nxCoreMsg) {
        if (nxCoreMsg.MessageType ==  defines.NxMSG_TRADE) {
            NxCoreHeader header = nxCoreMsg.coreHeader;
            String symbol = header.pnxStringSymbol.String;
            NxTime timestamp = header.nxExgTimestamp;
            String exchange = GetDefinedString(defines.NxST_EXCHANGE, header.ReportingExg).split("\\|")[0];
            
            NxCoreTrade trade = nxCoreMsg.coreData.Trade;
            double price = PriceToDouble(trade.Price,trade.PriceType);
            int size = trade.Size;
            long sequence = trade.ExgSequence;
			
            String conditions = "";
            for (int condition : trade.ExtTradeConditions)
                conditions += GetDefinedString(defines.NxST_TRADECONDITION, condition) + "|";
			
            String eligibility = "";
            if ((trade.ConditionFlags) !=0 ) {
                eligibility += "(Doesn't set";
                if ((trade.ConditionFlags & defines.NxTCF_NOHIGH) !=0 )
                    eligibility += " high";
                if ((trade.ConditionFlags & defines.NxTCF_NOLOW) !=0 )
                    eligibility += " low";
                if ((trade.ConditionFlags & defines.NxTCF_NOLAST) !=0 )
                    eligibility += " last";
                eligibility += ")";
            }
            if((trade.PriceFlags & defines.NxTPF_EXGCANCEL) !=0 )
                System.out.println("Cancel for " + symbol + " at "
                    + " sequence " + sequence + " on " + exchange
                    + " for " + size + " shares at $" + String.format("%.2f", price));
            else
                System.out.println("Trade for " + symbol + " at "
                    + String.format("%02d:%02d:%02d", timestamp.Hour, timestamp.Minute, timestamp.Second)
                    + " sequence " + sequence + " on " + exchange
                    + " for " + size + " shares at $" + String.format("%.2f", price)
                    + " conditions: " + conditions + eligibility);
        }
        return defines.NxCALLBACKRETURN_CONTINUE;
    }
    
    public static void main(String args[]) {
        TradeSample nxCore = new TradeSample();
        
        if (args.length > 1 && nxCore.LoadNxCore(args[0]) != 0){
            int returnValue = nxCore.ProcessTape(args[1], 0, 0, 0);
            nxCore.ProcessReturnValue(returnValue);
        }
		else
			System.out.println("loading library failed");
    }
}