import net.nanex.NxCoreClass;
class OptionSample {
    public static void main(String args[]) throws InterruptedException {
        if(args.length < 2)
			return;
		
		Thread[] threads = {
		    new Thread(new NxCoreThread(args[0],args[1],2)),
		    new Thread(new NxCoreThread(args[0],args[1],20)),
		    new Thread(new NxCoreThread(args[0],args[1],21)),
		    new Thread(new NxCoreThread(args[0],args[1],22))
		};
		
		for(Thread thread : threads)
			thread.start();
		
        for(Thread thread : threads)
			thread.join();
    }
}

class NxCoreThread extends NxCoreClass implements Runnable {
	private String library;
	private String filename;
	private int threadPermission;
	private boolean successfulExclude = false;
	
	public NxCoreThread(String libraryPath, String tapePath,int perm) {
		this.library = libraryPath;
		this.filename = tapePath;
		this.threadPermission = perm;
	}
	
	public void run() {
		if(LoadNxCore(library) != 0){
			int returnValue = ProcessTape(filename, 0, defines.NxCF_EXCLUDE_CRC_CHECK | defines.NxCF_EXCLUDE_QUOTES, 0);
			ProcessReturnValue(returnValue);
		}
		else
			System.out.println("loading library failed");
	}
	
	@Override
	public int OnNxCoreCallback( NxCoreSystem nxCoreSys, NxCoreMessage nxCoreMsg) {
		if (nxCoreMsg.MessageType == defines.NxMSG_STATUS && !successfulExclude) {
			int[] optionPermissions = {2, 20, 21, 22};
			for (int permission : optionPermissions) {
				if (threadPermission != permission && ExcludeOpraExch(defines.NxPERMID_REMOVE | permission) != 0)
					return defines.NxCALLBACKRETURN_CONTINUE;
			}
			successfulExclude = true;
		}
		
		if (nxCoreMsg.MessageType ==  defines.NxMSG_TRADE) {
            NxCoreHeader header = nxCoreMsg.coreHeader;
			NxOptionHdr optionHeader = header.pnxOptionHdr;
			if (optionHeader != null){
				String symbol = header.pnxStringSymbol.String;
				NxTime timestamp = header.nxExgTimestamp;
				NxDate expireDate = optionHeader.nxExpirationDate;
				double strikePrice = PriceToDouble(optionHeader.strikePrice, 7);
				String contractType;
				if (optionHeader.PutCall == 1)
					contractType = "Put";
				else
					contractType = "Call";
				
				NxCoreTrade trade = nxCoreMsg.coreData.Trade;
				double price = PriceToDouble(trade.Price,trade.PriceType);
				int size = trade.Size;
				
				System.out.println("Trade for " + symbol + " " + contractType + " expiring " 
				    + String.format("%d%02d%02d", expireDate.Year, expireDate.Month, expireDate.Day) 
					+ "with strike $" + String.format("%.2f", strikePrice) + " at "
					+ String.format("%02d:%02d:%02d", timestamp.Hour, timestamp.Minute, timestamp.Second)
					+ " for " + size + " shares at $" + String.format("%.2f", price));
			}
        }
		return defines.NxCALLBACKRETURN_CONTINUE;
	}
}